
package com.deltadna.android.sdk;

import org.json.JSONException;
import org.json.JSONObject;

/**
 * Helper class to construct an event. Mainly a wrapper around a JSON object
 * for convenience.
 */
public class EventBuilder{
	private JSONObject mData = new JSONObject();
	/**
	 * Default constructor.
	 */
	public EventBuilder(){
	}
	/**
	 * Adds a game parameter to the event params object.  If the value is null it is ignored.
	 * 
	 * @param key Game parameter name.
	 * @param value The value of the game parameter.
	 * 
	 * @return Reference to instance object for convenience.
	 */
	public EventBuilder addParam(String key, Object value){
		if(value == null) return this;

		if(value instanceof ProductBuilder){
			ProductBuilder product = (ProductBuilder)value;
			value = product.toJSON();
			
		}else if(value instanceof EventBuilder){
			EventBuilder eventParams = (EventBuilder)value;
			value = eventParams.toJSON();
		}

		try {
			mData.put(key, value);
		} catch (JSONException e) {}
		
		return this;
	}
	/**
	 * Returns a JSON representation of the EventBuilder.
	 * 
	 * @return A JSON representation of the EventBuilder.
	 */
	public JSONObject toJSON(){
		return mData;
	}
}

