package com.deltadna.android.sdk.helpers;

/**
 * General utils class.
 */
public class Utils{
	/**
	 * Constructs a big endian integer from the given big endian ordered
	 * byte data.
	 * 
	 * @param bytes The bytes to use.
	 * 
	 * @return The integer result.
	 */
	static public int toInt32(byte[] bytes){
		int result = 0;
		
		result = ((bytes[0] & 0xff) << 24) | ((bytes[1] & 0xff) << 16) | ((bytes[2] & 0xff) << 8) | (bytes[3] & 0xff);
		
		return result;
	}
	/**
	 * Encodes the given big endian integer to a big endian ordered array of bytes.
	 * 
	 * @param value The integer value to encode.
	 * 
	 * @return The encoded bytes.
	 */
	static public byte[] toBytes(int value){
		byte[] result = new byte[4];
		
		result[3] = (byte)(value & 0xff);
		result[2] = (byte)((value >> 8) & 0xff);
		result[1] = (byte)((value >> 16) & 0xff);
		result[0] = (byte)((value >> 24) & 0xff);
		
		return result;
	}
	final protected static char[] hexArray = "0123456789ABCDEF".toCharArray();
	/**
	 * Converts the given byte array to a hex encoded string.
	 * 
	 * @param bytes The bytes to encode.
	 * 
	 * @return The hex encoded string.
	 */
	static public String bytesToHex(byte[] bytes) {
	    char[] hexChars = new char[bytes.length * 2];
	    for ( int j = 0; j < bytes.length; j++ ) {
	        int v = bytes[j] & 0xFF;
	        hexChars[j * 2] = hexArray[v >>> 4];
	        hexChars[j * 2 + 1] = hexArray[v & 0x0F];
	    }
	    return new String(hexChars);
	}
	/**
	 * Tests if a given string reference is null or of zero length.
	 * 
	 * @param s The string to test.
	 * 
	 * @return TRUE if the string is NULL or zero length, FALSE otherwise.
	 */
	static public boolean isNullOrEmpty(String s){
		return (s == null) || (s.length() == 0);
	}
}
