package com.deltadna.android.sdk.example;

import org.json.JSONException;
import org.json.JSONObject;

import com.deltadna.android.sdk.DDNA;
import com.deltadna.android.sdk.DDNAPopupActivity;
import com.deltadna.android.sdk.EventBuilder;
import com.deltadna.android.sdk.ProductBuilder;
import com.deltadna.android.sdk.helpers.NotStartedException;
import com.deltadna.android.sdk.net.DDNANetManager;
import com.deltadna.android.sdk.net.DDNANetReq;
import com.deltadna.android.sdk.net.DDNANetReqCb;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;


public class DDNAExampleActivity extends Activity {

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		setContentView(R.layout.ddna_example_activity);

		//DDNA.inst().clearPersistentData();

		// Start deltaDNA SDK        
		final String environmentKey 	= "07575004106474324897044893014183";
		final String collectHostname 	= "http://collect3347ndrds.deltadna.net/collect/api";
		final String engageHostname		= "http://engage3347ndrds.deltadna.net";
		final String engageTestHostname = "http://www.deltadna.net/qa/engage";

		// SDK generates its own userID when null is passed
		DDNA.inst().startSDK(environmentKey, collectHostname, engageHostname , null);

		final TextView lblUserId = (TextView) findViewById(R.id.lblUserId);
		lblUserId.setText(DDNA.inst().userID());

		// Setup Upload Button
		// -------------------
		final Button buttonUpload = (Button) findViewById(R.id.btnUpload);
		buttonUpload.setOnClickListener(new View.OnClickListener() {
			public void onClick(View v) {
				Log.d("buttonUpload", "buttonUpload clicked");
				try {
					DDNA.inst().upload();

				} catch (NotStartedException e) {
					showDialog("DDNA Exception", "DDNA SDK not started.");
				}	
			}
		});

		// Setup Simple Event Button
		// -------------------------
		final Button buttonSimpleEvent = (Button) findViewById(R.id.btnSimple);
		buttonSimpleEvent.setOnClickListener(new View.OnClickListener() {			
			public void onClick(View v) {
				try {
					DDNA.inst().recordEvent("simpleEvent");
				} catch (NotStartedException e) {
					showDialog("DDNA Exception", "DDNA SDK not started.");
				}			
			}
		});

		// Setup Basic Event Button
		// ------------------------
		final Button buttonBasicEvent = (Button) findViewById(R.id.btnBasic);
		buttonBasicEvent.setOnClickListener(new View.OnClickListener() {

			public void onClick(View v) {

				// Create some Event Parameters
				EventBuilder eventBuilder = new EventBuilder();
				eventBuilder.addParam("clientVersion", "1.03.00");
				eventBuilder.addParam("serverVersion", "1.02.00");
				eventBuilder.addParam("dataVersion"  , "1.02.05");

				try {
					DDNA.inst().recordEvent("basicEvent", eventBuilder);
				} catch (NotStartedException e) {
					showDialog("DDNA Exception", "DDNA SDK not started.");
				}		
			}
		});

		// Setup Complex Event Button
		// -------------------------
		final Button buttonComplexEvent = (Button) findViewById(R.id.btnComplex);
		buttonComplexEvent.setOnClickListener(new View.OnClickListener() {
			public void onClick(View v) {
				EventBuilder transactionParams = new EventBuilder()
				.addParam("transactionName", "IAP - Large Treasure Chest")
				.addParam("transactionID", "47891208312996456524019-178.149.115.237:51787")
				.addParam("transactorID", "62.212.91.84:15116")
				.addParam("productID", "4019")
				.addParam("transactionServer", "GOOGLE")
				.addParam("transactionReceipt", "ewok9Ja81............991KS==")
				.addParam("transactionType", "PURCHASE")            
				.addParam("productsReceived", new ProductBuilder()
					.addItem("Golden Battle Axe", "Weapon", 1)
					.addItem("Mighty Flaming Sword of the First Age", "Legendary Weapon", 1)
					.addItem("Jewel Encrusted Shield", "Armour", 1)
					.addVirtualCurrency("Gold", "PREMIUM", 100))
				.addParam("productsSpent", new ProductBuilder()
					.addRealCurrency("USD", 499));

				try {
					DDNA.inst().recordEvent("transaction", transactionParams);
				} catch (NotStartedException e) {
					e.printStackTrace();
				}			
			}
		});

		// Setup Engage Button
		// -------------------
		final Button buttonEngage = (Button) findViewById(R.id.btnEngage);
		buttonEngage.setOnClickListener(new View.OnClickListener() {			
			public void onClick(View v) {
				// Make Engage Request				
				JSONObject params = new JSONObject();
				try {
					params.put("userLevel",4);
					params.put("userXP",1000);
					params.put("missionName", "Diso Volante");	
				} catch (JSONException e1) {}

				try {
					DDNA.inst().requestEngagement("testEngage", null, new TestEngageCb());
				}catch(NotStartedException e){
					e.printStackTrace();
				}
			}
		});

		// Setup Image Message Button
		// --------------------------
		final Button buttonImgMsg = (Button) findViewById(R.id.btnImgMsg);
		buttonImgMsg.setOnClickListener(new View.OnClickListener() {			
			public void onClick(View v) {
				// Make Image Message Request				
				//JSONObject params = new JSONObject();

				try {
					DDNA.inst().requestImageMessage("testImageMessage", null, new TestImageMsgCb());
				}catch(NotStartedException e){
					e.printStackTrace();
				}
			}
		});

		// Setup Notification Opened Button
		// --------------------------------
		final Button buttonNotification = (Button) findViewById(R.id.buttonNotification);
		buttonNotification.setOnClickListener(new View.OnClickListener() {
			public void onClick(View v) {
				// Pretend we got a push notification
				Bundle extras = new Bundle();
				extras.putInt(DDNA.EXTRA_PUSH_NOTIFICATION_ID, 1);
				extras.putString(DDNA.EXTRA_PUSH_NOTIFICATION_NAME, "Test Notification");
				extras.putBoolean(DDNA.EXTRA_PUSH_NOTIFICATION_LAUNCH, true);

				try {
					DDNA.inst().recordPushNotification(extras);
				} catch (NotStartedException e) {
					e.printStackTrace();
				}
			}
		});

		// Stop SDK
		// ----------
		final Button buttonStopSdk = (Button) findViewById(R.id.buttonStopSdk);
		buttonStopSdk.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				try {
					DDNA.inst().stopSDK();
				} catch (NotStartedException e) {
					e.printStackTrace();
				}

			}
		});

		// Start SDK
		// ----------
		final Button buttonStartSdk = (Button) findViewById(R.id.buttonStartSdk);
		buttonStartSdk.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				DDNA.inst().startSDK(environmentKey, collectHostname, engageHostname , null);
			}
		});
	}
	@Override
	public void onDestroy(){
		super.onDestroy();
		try {
			DDNA.inst().stopSDK();
		} catch (NotStartedException e) {
			e.printStackTrace();
		}
	}
	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);

		if(requestCode == DDNA.RESULTCODE_IMGMESSAGE){
			if(resultCode == Activity.RESULT_OK){
				Bundle extras = data.getExtras();

				String value = extras.getString(DDNA.EXTRA_DDNAVALUE);
				String params = extras.getString(DDNA.EXTRA_DDNAPARAMS);

				showDialog("Image Message", "Now we are back in the game with the message values: " + value + " and params: " + params);
			}else if(resultCode == Activity.RESULT_CANCELED){
				showDialog("Image Message", "We have dismissed the message with no action.");
			}
		}
	}

	// Display a Dialog Alert
	// ----------------------
	public void showDialog(final String dialogTitle, final String dialogText){
		runOnUiThread(new Runnable() {
			@Override
			public void run() {
				AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(DDNAExampleActivity.this);

				// set title
				alertDialogBuilder.setTitle(dialogTitle);

				// set dialog message
				alertDialogBuilder
						.setMessage(dialogText)
						.setCancelable(false)
						.setNegativeButton("OK", new DialogInterface.OnClickListener() {
							public void onClick(DialogInterface dialog, int id) {
								// if this button is clicked, close
								// current activity
								dialog.dismiss();
							}
						});

				// create alert dialog
				AlertDialog alertDialog = alertDialogBuilder.create();

				// show it
				alertDialog.show();
			}
		});
	}

	/**
	 *
	 */
	private class TestEngageCb implements DDNANetReqCb{
		/**
		 * 
		 * @param userCb
		 */
		public TestEngageCb(){}
		@Override
		public void done(DDNANetReq req) {
			Log.d(DDNA.LOGTAG, "Using live engagement (app cb)");
		}
		@Override
		public void progress(DDNANetReq req) {}
		@Override
		public void failed(DDNANetReq req) {
			Log.w(DDNA.LOGTAG, "Engage request failed(app cb).");
		}
	}

	/**
	 *
	 */
	private class TestImageMsgCb implements DDNANetReqCb{
		/**
		 * 
		 * @param userCb
		 */
		public TestImageMsgCb(){}
		@Override
		public void done(DDNANetReq req) {

			try {
				JSONObject json = new JSONObject(req.responseData().toString());
				if (json.has("image")) {

					Intent intent = new Intent(DDNAExampleActivity.this, DDNAPopupActivity.class);

					intent.putExtra(DDNA.EXTRA_IMGMESSAGE, json.toString());

					DDNAExampleActivity.this.startActivityForResult(intent, DDNA.RESULTCODE_IMGMESSAGE);
				}
				else {
					showDialog("Image Message", "Engage didn't return a valid image message.");
				}
			} catch (JSONException e) {
				showDialog("Image", "Engage didn't return a valid response.");
			}
		}
		@Override
		public void progress(DDNANetReq req) {}
		@Override
		public void failed(DDNANetReq req) {
		}
	}
}
//---------------------------------------------------------------------------------
